# Motrack-motion

Extension of [Motrack](https://github.com/Robotmurlock/Motrack) framework
for multi-object-tracking specialized in motion models and filters.
These models can be used as drop-in replacement for Kalman filter
in popular MOT algorithms.
